/* Copyright 2020-2021 MultiMC Contributors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#pragma once

#include <QString>
#include "settings/SettingsObject.h"

namespace Technic {
// not exporting it, only used in SingleZipPackInstallTask, InstanceImportTask and SolderPackInstallTask
class TechnicPackProcessor : public QObject {
    Q_OBJECT

   signals:
    void succeeded();
    void failed(QString reason);

   public:
    void run(SettingsObjectPtr globalSettings,
             const QString& instName,
             const QString& instIcon,
             const QString& stagingPath,
             const QString& minecraftVersion = QString(),
             bool isSolder = false);
};
}  // namespace Technic
